@@ -47,19 +47,6 @@
 #include <X11/cursorfont.h>
 #include <gdk/gdkprivate.h>
 
-#ifdef HAVE_LIBJPEG
-#include <jpeglib.h>
-#endif
-#ifdef HAVE_LIBPNG
-#include <png.h>
-#endif
-#ifdef HAVE_LIBTIFF
-#include <tiffio.h>
-#endif
-#ifdef HAVE_LIBGIF
-#include <gif_lib.h>
-#endif
-
 #define BYTE_ORD_24_RGB 0
 #define BYTE_ORD_24_RBG 1
 #define BYTE_ORD_24_BRG 2
@@ -171,25 +158,6 @@ void                _gdk_imlib_nullify_image(GdkImlibImage * im);
 /* char *g_SplitID(char *file); */
 char               *_gdk_imlib_GetExtension(char *file);
 
-#ifdef HAVE_LIBJPEG
-unsigned char      *_gdk_imlib_LoadJPEG(FILE * f, int *w, int *h);
-
-#endif /* HAVE_LIBJPEG */
-#ifdef HAVE_LIBPNG
-unsigned char      *_gdk_imlib_LoadPNG(FILE * f, int *w, int *h, int *t);
-
-#endif /* HAVE_LIBPNG */
-#ifdef HAVE_LIBTIFF
-unsigned char      *_gdk_imlib_LoadTIFF(FILE *f, char *file, int *w, int *h, int *t);
-
-#endif /* HAVE_LIBTIFF */
-#ifdef HAVE_LIBGIF
-unsigned char      *_gdk_imlib_LoadGIF(FILE *f, int *w, int *h, int *t);
-
-#endif /* HAVE_LIBGIF */
-unsigned char      *_gdk_imlib_LoadBMP(FILE *f, int *w, int *h, int *t);
-unsigned char      *_gdk_imlib_LoadXPM(FILE *f, int *w, int *h, int *t);
-unsigned char      *_gdk_imlib_LoadPPM(FILE * f, int *w, int *h);
 int                 _gdk_imlib_ispnm(FILE *f);
 int                 _gdk_imlib_isjpeg(FILE *f);
 int                 _gdk_imlib_ispng(FILE *f);
@@ -230,3 +198,31 @@ ter=&(Der2[Dex-6]);\
 (*ter)+=Der>>4;ter++;\
 (*ter)+=Deg>>4;ter++;\
 (*ter)+=Deb>>4;
+
+typedef unsigned char *(*gdk_imlib_loader_fn) (FILE *, int *w, int *h, int *transp);
+typedef unsigned char *(*gdk_imlib_loader_fn2)(FILE *, char *fname, int *w, int *h, int *trans);
+
+extern gdk_imlib_loader_fn _gdk_imlib_LoadBMP;
+extern gdk_imlib_loader_fn _gdk_imlib_LoadXPM;
+extern gdk_imlib_loader_fn _gdk_imlib_LoadGIF;
+extern gdk_imlib_loader_fn2 _gdk_imlib_LoadTIFF;
+extern gdk_imlib_loader_fn _gdk_imlib_LoadJPEG;
+extern gdk_imlib_loader_fn _gdk_imlib_LoadPNG;
+extern gdk_imlib_loader_fn _gdk_imlib_LoadPPM;
+
+typedef gint (*gdk_imlib_saver_fn)(GdkImlibImage *im, char *file, GdkImlibSaveInfo *info);
+
+extern gdk_imlib_saver_fn _gdk_imlib_SavePNG;
+extern gdk_imlib_saver_fn _gdk_imlib_SaveTIFF;
+extern gdk_imlib_saver_fn _gdk_imlib_SavePNG;
+extern gdk_imlib_saver_fn _gdk_imlib_SaveJPEG;
+extern gdk_imlib_saver_fn _gdk_imlib_SavePS;
+extern gdk_imlib_saver_fn _gdk_imlib_SavePPM;
+
+typedef GdkImlibImage * (*gdk_imlib_inline_fn)(unsigned char *data, int data_size);
+
+extern gdk_imlib_inline_fn _gdk_imlib_inlined_png_to_image;
+
+typedef GdkImlibImage *(*gdk_imlib_load_alpha_fn)(char *file);
+
+extern gdk_imlib_load_alpha_fn _gdk_imlib_load_alpha_png;
